pub struct Credential<'a> {
pub issuer_pk: PublicKey<'a>,
pub signature: Signature<'a>,
pub payload: &'a [u8],
}Expand description
One link in a serialized credential chain as it appears on the wire.
Fields
issuer_pk: PublicKey<'a>Public key of the identity that signed this credential.
signature: Signature<'a>ML-DSA-65 signature over payload.
payload: &'a [u8]Signed payload bytes.